
from say.vertical import *
import pytest


def test_basic():
    assert Vertical(0,0).render() == ([], [])
    assert Vertical(1,1).render() == ([''], [''])
    assert Vertical(1,2).render() == ([''], ['', ''])
    assert Vertical(2,1).render() == (['', ''], [''])
    assert Vertical(2,3).render() == (['', ''], ['', '', ''])


def test_repr():
    assert repr(Vertical(1, 2, 'x', 'y')) == \
        "Vertical(before=1, after=2, bstr='x', astr='y')"


def test_strings():
    assert Vertical(0,0,'x','y').render() == ([], [])
    assert Vertical(1,1,'x','y').render() == (['x'], ['y'])
    assert Vertical(1,2,'x','y').render() == (['x'], ['y', 'y'])
    assert Vertical(2,1,'x','y').render() == (['x', 'x'], ['y'])
    assert Vertical(2,3,'x','y').render() == (['x', 'x'], ['y', 'y', 'y'])
    assert Vertical(2,0,'x','y').render() == (['x', 'x'], [])
    assert Vertical(0,3,'x','y').render() == ([], ['y', 'y', 'y'])


def test_memoization():
    assert Vertical(0,0,'x','y') is Vertical(0,0,'x','y')
    assert Vertical(0,3,'x','y') is Vertical(0,3,'x','y')
    assert Vertical(before=1, after=1, bstr='', astr='') is Vertical(before=1, after=1, bstr='', astr='')


def test_vertical():
    assert vertical() is vertical(0) # works
    assert vertical() == vertical(0)
    assert vertical(0) is Vertical(0,0,'','') # works
    assert vertical(0) == Vertical(0,0,'','')
    

@pytest.mark.skipif('True', reason='road out')
def test_vertical_two():
    assert vertical(1) is Vertical(1,1,'','') # breaks
    assert vertical(1,2) is Vertical(1,2,'','')

    # breaking because vertical(1) has different instance signature than
    # Vertical(1,1,'','')

    # presumably fixable...
    # but not clear why this contstructor was interesting in the first place



#!/usr/bin/env python

from setuptools import setup
import sys
from codecs import open

_PY3 = sys.version_info[0] == 3
_PY26 = sys.version_info[0] == (2, 6)

def lines(text):
    """
    Returns each non-blank line in text enclosed in a list.
    See http://pypi.python.org/pypi/textdata for more sophisticated version.
    """
    return [l.strip() for l in text.strip().splitlines() if l.strip()]

STUF = 'stuf==0.9.14' if _PY26 else 'stuf>=0.9.16'

setup(
    name='say',
    version='1.3.9',
    author='Jonathan Eunice',
    author_email='jonathan.eunice@gmail.com',
    description='Simple, highly-functional templated printing. say("Hello, {name}!", indent=1)',
    long_description=open('README.rst', encoding='utf-8').read(),
    url='https://bitbucket.org/jeunice/say',
    license='Apache License 2.0',
    packages=['say'],
    setup_requires=[],
    install_requires=['six>=1.9', STUF, 'options>=1.3.1', 'simplere>=1.2.7',
                      'mementos>=1.2.0', 'ansicolors'],
    tests_require=['tox', 'pytest', 'six'],
    zip_safe=False,
    keywords='print format template interpolate say',
    classifiers=lines("""
        Development Status :: 4 - Beta
        Operating System :: OS Independent
        License :: OSI Approved :: Apache Software License
        Intended Audience :: Developers
        Programming Language :: Python
        Programming Language :: Python :: 2
        Programming Language :: Python :: 2.7
        Programming Language :: Python :: 3
        Programming Language :: Python :: 3.2
        Programming Language :: Python :: 3.3
        Programming Language :: Python :: 3.4
        Programming Language :: Python :: 3.5
        Programming Language :: Python :: Implementation :: CPython
        Programming Language :: Python :: Implementation :: PyPy
        Topic :: Software Development :: Libraries :: Python Modules
        Topic :: Printing
    """)
)
